@@ -9,19 +9,22 @@ from loguru import logger
 regex = ['小于', '小于等于', '小于或等于', '大于1.0并且小于', '大于', '大于等于', '大于或等于',  '等于', '不得大于',
          '高于',
          '低于', '不超过', '以上', '以下', '以内', '＞', '>', '≧', '≥', '-', '—', '~', '=',
-           '≮', '大于1.0并且小于', '且', '并且', '＜', '<', '≦', '≤',  '＝', '≯', '上限','超过','不低']
+           '≮', '大于1.0并且小于', '且', '并且', '＜', '<', '≦', '≤',  '＝', '≯', '上限','超过','不低','FAR']
 min_regex=['大于1.0并且小于', '大于', '大于等于', '大于或等于',  '等于','高于',
           '以上',   '＞', '>', '≧', '≥', '-', '—', '~', '=',
            '≮', '大于1.0并且小于', '且', '并且',   '＝',  '超过']
+
+
 def calculate_maxi_min_rjl(data):
-    if data is None or data == '' or str(data)=='nan':
+    if data is None or data == '' or str(data) == 'nan':
         return {'max_rongjilv': '', 'min_rongjilv': ''}
     if '地下' in data:
-        data=data.split('地下')[0]
+        data = data.split('地下')[0]
     if '（' in data:
         data = re.sub('（.*?）', '', data)
 
-    lst = re.findall(r'[0-9|.]+', data)
+    lst = re.findall(r'[0-9|(.]+', data)
+
     for _ in range(len(lst)):
 
         if '不大于' in data:
@@ -52,58 +55,57 @@ def calculate_maxi_min_rjl(data):
             data = data.replace('大于等于', '大于')
         elif '小于或等于' in data:
             data = data.replace('小于或等于', '小于')
-
-
-
-
+        elif '-' in data:
+            data = data.replace('-', '≤容积率≤')
+        if 'FAR' in data:
+            data = data.replace('FAR', '容积率')
 
     try:
-        lst = re.findall(r'[0-9|.]+', data)
+        lst = re.findall(r'[0-9|(.]+', data)
+        max_list = list()
+        min_list = list()
         max_rongjilv = None
         min_rongjilv = None
         max_r = max(lst)
         min_r = min(lst)
         if max_r == min_r:
-            if '小于' in data or '小于等于' in data or '小于或等于' in data or '不大于' in data  or '等于' in data or '不得大于' in data or '不高于' in data or '低于' in data or '不超过' in data or '以下' in data or '以内' in data or '＜' in data or '<' in data or '≦' in data or '≤' in data or '<=' in data or '＜＝' in data or '≯' in data or '上限' in data:
+            if '小于' in data or 'FAR' in data or '小于等于' in data or '小于或等于' in data or '不大于' in data or '等于' in data or '不得大于' in data or '不高于' in data or '低于' in data or '不超过' in data or '以下' in data or '以内' in data or '＜' in data or '<' in data or '≦' in data or '≤' in data or '<=' in data or '＜＝' in data or '≯' in data or '上限' in data:
                 min_rongjilv = ''
                 max_rongjilv = max_r
-            elif '大于' in data or '大于等于' in data or '大于或等于' in data or '不小于' in data or '不低于' in data or '高于' in data or '不少于' in data or '以上' in data or '＞' in data or '>' in data or '≧' in data or '≥' in data or '>=' in data or '＞＝' in data or '≮' in data or '＝' in data or '不低' in data:
+            elif '大于' in data or 'FAR' in data or '大于等于' in data or '大于或等于' in data or '不小于' in data or '不低于' in data or '高于' in data or '不少于' in data or '以上' in data or '＞' in data or '>' in data or '≧' in data or '≥' in data or '>=' in data or '＞＝' in data or '≮' in data or '＝' in data or '不低' in data:
                 min_rongjilv = min_r
                 max_rongjilv = ''
             else:
                 min_rongjilv = max_r
                 max_rongjilv = max_r
-
-
-
-
-
         else:
+            for td in lst:
 
-            while lst:
+                for i in ['小于', 'FAR', '小于等于', '小于或等于', '不大于', '等于', '不得大于', '不高于', '低于', '不超过', '以下', '以内', '＜', '<',
+                          '≦',
+                          '≤', '<=', '＜＝', '≯', '上限']:
+                    if i + str(td) in data:
+                        max_list.append(td)
+                for j in ['大于', 'FAR', '大于等于', '大于或等于', '不小于', '不低于', '高于', '不少于', '以上', '＞', '>', '≧', '≥', '>=', '＞＝',
+                          '≮', '＝', '不低']:
+                    if j + str(td) in data or str(td) + j in data:
+                        min_list.append(td)
+                if len(lst) > 0 and not max_list and not min_list:
+                    min_list.append(td)
+            if max_list:
+                max_rongjilv = max(max_list)
+            else:
+                max_rongjilv = ''
+            if min_list:
+                min_rongjilv = min(min_list)
+            else:
+                min_rongjilv = ''
 
-                max_r = max(lst)
-                min_r = min(lst)
-                for j in regex:
-                    if j + str(max_r) in data:
-                        max_rongjilv = max_r
-                        break
-                for i in regex:
-                    if i+str(min_r) in data or str(min_r) + i in data:
-                        min_rongjilv = min_r
-                        break
 
-                if max_rongjilv and min_rongjilv:
-                    break
-                elif max_rongjilv:
-                    lst.remove(min_r)
-                elif min_rongjilv:
-                    lst.remove(max_r)
-                else:
-                    lst.remove(max_r)
-                    lst.remove(min_r)
 
         return {'max_rongjilv': max_rongjilv, 'min_rongjilv': min_rongjilv}
+
+
     except Exception as e:
         print(e)
         logger.debug(f'解析失败数据为：{data}')
@@ -173,7 +175,8 @@ def calculate_maxi_min_lhl(data):
                         max_lhl = max_lhl
                         break
                 for i in regex:
-                    if str(min_lhl) + i in data:
+                    if i+str(min_lhl) in data or str(min_lhl) + i in data  :
+
                         min_lhl = min_lhl
                         break
 
@@ -291,5 +294,5 @@ def read_csv():
 
 if __name__ == '__main__':
     # data=['20%＜绿地率','绿地率≥25%','0.9> 小于1.0','1.0<容积率＜3.0，容积率≯2.0, 容积率>4.0','居住用地  ≤2.6；  商业用地  ≤2.5', '小于1.6、S2;小于1.8大于1.0', '小于1.8大于1.0、S2;小于1.6', 'S1：不大于1.8不小于1.0、S2;不大于1.6']
-    data=['35.13','1.49','≧32.64％','≥35.2','绿地率≥32.5%','≥32.5%']
-    print(calculate_maxi_min_rjl(data[1]))
+    data=['居住1.0 商业≤0.6']
+    print(calculate_maxi_min_rjl(data[0]))
